<?php

/**
 * Administrative settings form.
 */
function protected_forms_config() {
  $form = array();

  $form['#attached']['css'] = array(
    drupal_get_path('module', 'protected_forms') . '/css/protected_forms.css',
  );
  $form['header'] = array(
    '#markup' => '<p>' . t('Make sure the <a href="@permissions">permissions</a> are set correctly for the <em>Protected Forms</em> to work as expected.', array('@permissions' => '/admin/people/permissions#module-protected_forms'))  . '</p>',
  );

  // Miscellaneous settings.
  $form['misc'] = array(
    '#type' => 'fieldset',
    '#title' => t('Miscellaneous settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['misc']['protected_forms_excluded_forms'] = array(
    '#type' => 'textarea',
    '#rows' => 3,
    '#columns' => 60,
    '#default_value' => _variable_get('protected_forms_excluded_forms'),
    '#title' => t('Excluded forms'),
    '#required' => FALSE,
    '#description' => t('Enter ids of those forms submissions to which should always pass by separating them with commas or new lines.'),
  );
  // Message displayed to users when submission is rejected.
  $form['misc']['protected_forms_reject_message'] = array(
    '#type' => 'textarea',
    '#rows' => 3,
    '#columns' => 60,
    '#default_value' => _variable_get('protected_forms_reject_message'),
    '#title' => t('Reject message'),
    '#required' => TRUE,
    '#description' => t('Enter a message to display when submission of undesired pattern is attempted.'),
  );
  // Give users option to enable/disable logging if Database Logging is on.
  if (module_exists('dblog')) {
    $form['misc']['protected_forms_log_rejected'] = array(
      '#type' => 'checkbox',
      '#title' => t('Log rejected submissions?'),
      '#default_value' => _variable_get('protected_forms_log_rejected'),
      '#description' => t('Enable logging if you want to analyze rejected posts or start banning spammers based on their IP addresses.'),
    );
  }
  // Option for setting a threshold to ban a spamming IP address.
  $form['misc']['protected_forms_ban_threshold'] = array(
    '#type' => 'textfield',
    '#states' => array(
      // Only show this field when the 'log_rejected' checkbox is enabled.
      'visible' => array(
        ':input[name="protected_forms_log_rejected"]' => array('checked' => TRUE),
      ),
    ),
    '#size' => 3,
    '#default_value' => _variable_get('protected_forms_ban_threshold'),
    '#title' => t('Threshold for banning'),
    '#required' => TRUE,
    '#description' => t('Set how many times an IP must be caught spamming before it gets <a href="@banned">banned from the site</a>.', array('@banned' => '/admin/config/people/ip-blocking')),
  );

  // Validation steps.
  $form['validation_description'] = array(
    '#markup' => '<p>' . t('The <em>Protected Forms</em> module validates each submission through several conditions starting from simpler ones to gradually more complex ones such as a honeypot trap, a minimum threshold, language script checks, preset patterns, and rejecting it as soon as it fails any of the following steps. Only submissions that pass all checks are posted.') . '</p>',
  );
  $form['honeypot'] = array(
    '#type' => 'fieldset',
    '#title' => t('Step 1: Honeypot trap'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['honeypot']['protected_forms_honeypot_trap'] = array(
    '#type' => 'textfield',
    '#default_value' => _variable_get('protected_forms_honeypot_trap'),
    '#title' => t('Field name'),
    '#required' => TRUE,
    '#description' => t('A honeypot field is an anti-spam technique that baits bots into filling out this hidden field. Human users cannot see the field so they don\'t fill it out. You can use any name for this field that makes sense such as <em>url, website, name, e-mail, city, country,</em> etc, or any other custom name taken from a professional jargon or terminology of your website\'s industry or specialty.'),
  );
  $form['post_size'] = array(
    '#type' => 'fieldset',
    '#title' => t('Step 2: Post-size check'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['post_size']['protected_forms_post_size_threshold'] = array(
    '#type' => 'textfield',
    '#required' => TRUE,
    '#size' => 3,
    '#default_value' => _variable_get('protected_forms_post_size_threshold'),
    '#title' => t('Minimum post-size'),
    '#description' => t('Set a minimum threshold for number of characters in each post. Submissions containing less number of characters  than the set threshold are automatically rejected.'),
  );
  $form['language'] = array(
    '#type' => 'fieldset',
    '#title' => t('Step 3: Language checks'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  // Allowed language scripts.
  $unicode_character_ranges = _variable_get('protected_forms_unicode_character_ranges');
  $unicode_character_ranges_keys = array_keys($unicode_character_ranges);
  $form['language']['protected_forms_allowed_scripts'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Allowed language scripts'),
    '#required' => TRUE,
    '#options' => drupal_map_assoc($unicode_character_ranges_keys),
    '#default_value' => _variable_get('protected_forms_allowed_scripts'),
    '#description' => t('Select language scripts allowed for submission.'),
  );
  $form['language']['protected_forms_validate_percent'] = array(
    '#type' => 'textfield',
    '#default_value' => _variable_get('protected_forms_validate_percent'),
    '#title' => t('Percentage to validate'),
    '#size' => 3,
    '#required' => TRUE,
    '#description' => t('Spam texts can be constructed using mixed characters from multiple languages. Validating each
    character would cause performance overhead, especially with large texts submitted. Therefore, start with 20% of
    randomly selected characters to check, and if characters of disallowed languages start slipping in through the
    validation, then gradually increase it to the new optimum.'),
  );
  $form['patterns'] = array(
    '#type' => 'fieldset',
    '#title' => t('Step 4: Pattern checks'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $allowed_patterns = _variable_get('protected_forms_allowed_patterns');
  $form['patterns']['protected_forms_allowed_patterns'] = array(
    '#type' => 'textarea',
    '#rows' => 3,
    '#columns' => 60,
    '#default_value' => strtolower($allowed_patterns),
    '#title' => t('Allowed patterns'),
    '#required' => FALSE,
    '#description' => t('Enter protected words, patterns, professional jargon or terminology of your website\'s industry or specialty which should always pass the validation by separating them with commas or new lines.'),
  );
  // Reject patterns.
  $reject_patterns = _variable_get('protected_forms_reject_patterns');
  $form['patterns']['protected_forms_reject_patterns'] = array(
    '#type' => 'textarea',
    '#rows' => 5,
    '#columns' => 60,
    '#default_value' => strtolower($reject_patterns),
    '#title' => t('Reject patterns'),
    '#required' => TRUE,
    '#description' => t('Enter patterns to reject by separating them with commas or new lines. The longer each pattern, the less likely legitimate submissions are blocked. For example, the reject pattern <strong><em>WIN</em></strong> would prevent submissions of any post that contains words like <strong><em>groWINg</em></strong>, <strong><em>WINdows</em></strong>, etc., unless they are protected in the <strong>Allowed patterns</strong> section.'),
  );

  return system_settings_form($form);
}
